@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 2007 Till Adam <adam@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "timelineview_p.h"
@@ -31,14 +15,14 @@
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
 #include <Akonadi/Calendar/IncidenceChanger>
-#include <KCalCore/OccurrenceIterator>
+#include <KCalendarCore/OccurrenceIterator>
 
 #include "calendarview_debug.h"
 
 #include <QStandardItemModel>
 #include <QTreeWidget>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace EventViews;
 
 TimelineView::Private::Private(TimelineView *parent)
@@ -57,7 +41,7 @@ void TimelineView::Private::splitterMoved()
 
 void TimelineView::Private::itemSelected(const QModelIndex &index)
 {
-    TimelineSubItem *tlitem
+    auto *tlitem
         = dynamic_cast<TimelineSubItem *>(static_cast<QStandardItemModel *>(
                                               mGantt->model())->item(index.row(), index.column()));
     if (tlitem) {
@@ -67,7 +51,7 @@ void TimelineView::Private::itemSelected(const QModelIndex &index)
 
 void TimelineView::Private::itemDoubleClicked(const QModelIndex &index)
 {
-    TimelineSubItem *tlitem
+    auto *tlitem
         = dynamic_cast<TimelineSubItem *>(static_cast<QStandardItemModel *>(
                                               mGantt->model())->item(index.row(), index.column()));
     if (tlitem) {
@@ -79,7 +63,7 @@ void TimelineView::Private::contextMenuRequested(const QPoint &point)
 {
     QPersistentModelIndex index = mGantt->indexAt(point);
     // mHintDate = QDateTime( mGantt->getDateTimeForCoordX( QCursor::pos().x(), true ) );
-    TimelineSubItem *tlitem
+    auto *tlitem
         = dynamic_cast<TimelineSubItem *>(static_cast<QStandardItemModel *>(
                                               mGantt->model())->item(index.row(), index.column()));
     if (!tlitem) {
@@ -124,7 +108,7 @@ void TimelineView::Private::insertIncidence(const Akonadi::Item &aitem, const QD
     }
 
     if (incidence->recurs()) {
-        KCalCore::OccurrenceIterator occurIter(*(q->calendar()), incidence, QDateTime(day, QTime(0,
+        KCalendarCore::OccurrenceIterator occurIter(*(q->calendar()), incidence, QDateTime(day, QTime(0,
                                                                                                  0,
                                                                                                  0)), QDateTime(
                                                    day, QTime(23, 59, 59)));
@@ -157,14 +141,14 @@ void TimelineView::Private::insertIncidence(const Akonadi::Item &incidence)
     }
 
     for (QDate day = mStartDate; day <= mEndDate; day = day.addDays(1)) {
-        const KCalCore::Event::List events = q->calendar()->events(day,
+        const KCalendarCore::Event::List events = q->calendar()->events(day,
                                                              QTimeZone::systemTimeZone(),
-                                                             KCalCore::EventSortStartDate,
-                                                             KCalCore::SortDirectionAscending);
+                                                             KCalendarCore::EventSortStartDate,
+                                                             KCalendarCore::SortDirectionAscending);
         if (events.contains(event)) {
             //PENDING(AKONADI_PORT) check if correct. also check the original if,
             //was inside the for loop (unnecessarily)
-            for (const KCalCore::Event::Ptr &i : events) {
+            for (const KCalendarCore::Event::Ptr &i : events) {
                 Akonadi::Item item = q->calendar()->item(i);
                 insertIncidence(item, day);
             }
@@ -181,7 +165,7 @@ void TimelineView::Private::removeIncidence(const Akonadi::Item &incidence)
 #if 0 //AKONADI_PORT_DISABLED
       // try harder, the incidence might already be removed from the resource
         typedef QMap<QString, KOrg::TimelineItem *> M2_t;
-        typedef QMap<KCalCore::ResourceCalendar *, M2_t> M1_t;
+        typedef QMap<KCalendarCore::ResourceCalendar *, M2_t> M1_t;
         for (M1_t::ConstIterator it1 = d->mCalendarItemMap.constBegin();
              it1 != mCalendarItemMap.constEnd(); ++it1) {
             for (M2_t::ConstIterator it2 = it1.value().constBegin();
@@ -197,7 +181,7 @@ void TimelineView::Private::removeIncidence(const Akonadi::Item &incidence)
 
 void TimelineView::Private::itemChanged(QStandardItem *item)
 {
-    TimelineSubItem *tlit = dynamic_cast<TimelineSubItem *>(item);
+    auto *tlit = dynamic_cast<TimelineSubItem *>(item);
     if (!tlit) {
         return;
     }
@@ -207,7 +191,11 @@ void TimelineView::Private::itemChanged(QStandardItem *item)
 
     QDateTime newStart(tlit->startTime());
     if (inc->allDay()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         newStart = QDateTime(newStart.date());
+#else
+        newStart = QDateTime(newStart.date().startOfDay());
+#endif
     }
 
     int delta = tlit->originalStart().secsTo(newStart);
