@@ -1,42 +1,21 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "tododelegates.h"
 #include "todomodel.h"
 #include "todoviewview.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <AkonadiWidgets/TagSelectionComboBox>
 #include <CalendarSupport/CategoryConfig>
 #include <CalendarSupport/CategoryHierarchyReader>
-#include <LibkdepimAkonadi/TagSelectionCombo>
-
-#include <Libkdepim/KCheckComboBox>
-#include <LibkdepimAkonadi/TagWidgets>
 
 #include <KCalendarCore/CalFilter>
 
-#include <KComboBox>
 #include <KDateComboBox>
 
 #include <QApplication>
@@ -52,10 +31,6 @@ TodoCompleteDelegate::TodoCompleteDelegate(QObject *parent)
 {
 }
 
-TodoCompleteDelegate::~TodoCompleteDelegate()
-{
-}
-
 void TodoCompleteDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QStyleOptionViewItem opt = option;
@@ -66,7 +41,7 @@ void TodoCompleteDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
 
     if (index.data(Qt::EditRole).toInt() > 0) {
         bool isEditing = false;
-        TodoViewView *view = qobject_cast<TodoViewView *>(parent());
+        auto *view = qobject_cast<TodoViewView *>(parent());
         if (view) {
             isEditing = view->isEditing(index);
         }
@@ -116,7 +91,7 @@ QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionV
     Q_UNUSED(option);
     Q_UNUSED(index);
 
-    TodoCompleteSlider *slider = new TodoCompleteSlider(parent);
+    auto *slider = new TodoCompleteSlider(parent);
 
     slider->setRange(0, 100);
     slider->setOrientation(Qt::Horizontal);
@@ -126,14 +101,14 @@ QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void TodoCompleteDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    QSlider *slider = static_cast<QSlider *>(editor);
+    auto *slider = static_cast<QSlider *>(editor);
 
     slider->setValue(index.data(Qt::EditRole).toInt());
 }
 
 void TodoCompleteDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    QSlider *slider = static_cast<QSlider *>(editor);
+    auto *slider = static_cast<QSlider *>(editor);
 
     model->setData(index, slider->value());
 }
@@ -170,16 +145,12 @@ TodoPriorityDelegate::TodoPriorityDelegate(QObject *parent)
 {
 }
 
-TodoPriorityDelegate::~TodoPriorityDelegate()
-{
-}
-
 QWidget *TodoPriorityDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
 
-    QComboBox *combo = new QComboBox(parent);
+    auto *combo = new QComboBox(parent);
 
     combo->addItem(i18nc("@action:inmenu Unspecified priority", "unspecified"));
     combo->addItem(i18nc("@action:inmenu highest priority", "1 (highest)"));
@@ -197,14 +168,14 @@ QWidget *TodoPriorityDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void TodoPriorityDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    QComboBox *combo = static_cast<QComboBox *>(editor);
+    auto *combo = static_cast<QComboBox *>(editor);
 
     combo->setCurrentIndex(index.data(Qt::EditRole).toInt());
 }
 
 void TodoPriorityDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    QComboBox *combo = static_cast<QComboBox *>(editor);
+    auto *combo = static_cast<QComboBox *>(editor);
 
     model->setData(index, combo->currentIndex());
 }
@@ -224,30 +195,26 @@ TodoDueDateDelegate::TodoDueDateDelegate(QObject *parent)
 {
 }
 
-TodoDueDateDelegate::~TodoDueDateDelegate()
-{
-}
-
 QWidget *TodoDueDateDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
 
-    KDateComboBox *dateEdit = new KDateComboBox(parent);
+    auto *dateEdit = new KDateComboBox(parent);
 
     return dateEdit;
 }
 
 void TodoDueDateDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
+    auto *dateEdit = static_cast<KDateComboBox *>(editor);
 
     dateEdit->setDate(index.data(Qt::EditRole).toDate());
 }
 
 void TodoDueDateDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
+    auto *dateEdit = static_cast<KDateComboBox *>(editor);
 
     model->setData(index, dateEdit->date());
 }
@@ -268,30 +235,24 @@ TodoCategoriesDelegate::TodoCategoriesDelegate(QObject *parent)
 {
 }
 
-TodoCategoriesDelegate::~TodoCategoriesDelegate()
-{
-}
-
 QWidget *TodoCategoriesDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
 
-    return new KPIM::TagSelectionCombo(parent);
+    return new Akonadi::TagSelectionComboBox(parent);
 }
 
 void TodoCategoriesDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    KPIM::KCheckComboBox *combo = static_cast<KPIM::KCheckComboBox *>(editor);
-
-    combo->setCheckedItems(index.data(Qt::EditRole).toStringList(), Qt::UserRole);
+    auto *combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
+    combo->setSelection(index.data(Qt::EditRole).toStringList());
 }
 
 void TodoCategoriesDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    KPIM::KCheckComboBox *combo = static_cast<KPIM::KCheckComboBox *>(editor);
-
-    model->setData(index, combo->checkedItems(Qt::UserRole));
+    auto *combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
+    model->setData(index, combo->selectionNames());
 }
 
 void TodoCategoriesDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -315,10 +276,6 @@ TodoRichTextDelegate::TodoRichTextDelegate(QObject *parent)
     m_textDoc = new QTextDocument(this);
 }
 
-TodoRichTextDelegate::~TodoRichTextDelegate()
-{
-}
-
 void TodoRichTextDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     if (index.data(TodoModel::IsRichTextRole).toBool()) {
