@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todomodel_p.h"
@@ -27,7 +11,6 @@
 #include <CalendarSupport/Utils>
 #include <CalendarSupport/KCalPrefs>
 #include <KLocalizedString>
-#include <KCalendarCore/Todo>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Attachment>
 #include <KCalUtils/IncidenceFormatter>
@@ -37,7 +20,6 @@
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 
-#include <Akonadi/Calendar/ETMCalendar>
 
 #include <KMessageBox>
 #include "calendarview_debug.h"
@@ -70,7 +52,6 @@ static bool isDueToday(const KCalendarCore::Todo::Ptr &todo)
 }
 
 TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *qq) : QObject()
-    , m_changer(nullptr)
     , m_preferences(preferences)
     , q(qq)
 {
@@ -79,7 +60,7 @@ TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *
 Akonadi::Item TodoModel::Private::findItemByUid(const QString &uid, const QModelIndex &parent) const
 {
     Q_ASSERT(!uid.isEmpty());
-    IncidenceTreeModel *treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
+    auto *treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
     if (treeModel) {   // O(1) Shortcut
         return treeModel->item(uid);
     }
@@ -795,7 +776,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
 Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid()) {
-        return nullptr;
+        return Qt::NoItemFlags;
     }
 
     Qt::ItemFlags ret = QAbstractItemModel::flags(index);
@@ -807,7 +788,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
         Q_ASSERT(mapToSource(index).isValid());
         qCWarning(CALENDARVIEW_LOG) << "Item is invalid " << index;
         Q_ASSERT(false);
-        return nullptr;
+        return Qt::NoItemFlags;
     }
 
     ret |= Qt::ItemIsDragEnabled;
