@@ -1,26 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todoviewview.h"
@@ -36,8 +19,6 @@
 
 TodoViewView::TodoViewView(QWidget *parent)
     : QTreeView(parent)
-    , mHeaderPopup(nullptr)
-    , mIgnoreNextMouseRelease(false)
 {
     header()->installEventFilter(this);
     setAlternatingRowColors(true);
@@ -56,7 +37,7 @@ bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
 {
     Q_UNUSED(watched);
     if (event->type() == QEvent::ContextMenu) {
-        QContextMenuEvent *e = static_cast<QContextMenuEvent *>(event);
+        auto *e = static_cast<QContextMenuEvent *>(event);
 
         if (!mHeaderPopup) {
             mHeaderPopup = new QMenu(this);
@@ -73,7 +54,7 @@ bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
             connect(mHeaderPopup, &QMenu::triggered, this, &TodoViewView::toggleColumnHidden);
         }
 
-        foreach (QAction *action, mColumnActions) {
+        for (QAction *action : qAsConst(mColumnActions)) {
             int column = action->data().toInt();
             action->setChecked(!isColumnHidden(column));
         }
