@@ -1,20 +1,8 @@
 /*
-    Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-    Author: Kevin Krammer, krake@kdab.com
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainwindow.h"
@@ -28,7 +16,7 @@
 #include "timeline/timelineview.h"
 #include "prefs.h"
 #include "calendarview_debug.h"
-#include <calendarsupport/collectionselection.h>
+#include <CalendarSupport/CollectionSelection>
 
 #include <Akonadi/Calendar/IncidenceChanger>
 #include <KCalendarCore/Event>
